package Bundle::AndyA;

$VERSION = '1.000';

1;

__END__

=head1 NAME

Bundle::AndyA - Basic working environment.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::AndyA'>

=head1 CONTENTS

App::Ack

Bundle::LWP

CGI

CGI::Carp

CGI::Cookie

CGI::Fast

CGI::Pretty

CGI::Push

CGI::Simple

CPAN::Reporter

Class::Accessor

Class::Std

Config::General

Cwd

DBI

Data::Dumper::Simple

Data::Hexdumper

Devel::Cover

Devel::Profiler

Digest

Digest::MD5

File::Copy

File::Copy::Recursive

File::Find

File::Find::Parallel

File::HomeDir

File::Monitor

File::Next

File::Slurp

File::TinyLock

File::Which

File::chdir

File::pushd

HTML::Tiny

HTML::TokeParser

HTML::TokeParser::Simple

IO::Poll

IO::Select

Inline

Lingua::EN::Inflect

List::Util

Log::Log4perl

MIME::Base64

Mail::Internet

Mail::Mailer

Mail::Send

Mail::Util

Memoize

Module::Build

Module::CPANTS::Analyse

Module::Starter::PBP

Perl::Tidy

Perl::Version

Pod::Checker

Pod::Coverage

PPI

Regexp::Common

TAP::Parser

Template

Test::Class

Test::Deep

Test::Differences

Test::Exception

Test::Harness

Test::MockModule

Test::NoWarnings

Test::Pod

Test::Pod::Coverage

Test::Reporter

Test::WWW::Mechanize

Test::XML

WWW::Mechanize

XML::Descent

XML::Parser

XML::SemanticDiff

XML::Simple

XML::TokeParser

YAML

YAML::Syck

YAML::Tiny

=head1 DESCRIPTION

Nice things to have installed.

=head1 AUTHOR

Andy Armstrong <andy@hexten.net>